@@ -13,7 +13,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -23,12 +23,19 @@ use web service
 my $api = new WebService::Class::Twitter(username=>'username',password=>'password';
 my $result $cache_api->public_timeline();
 
-Cache manager use
+Cache manager use 
+
+file base cache
 
 my $cache_manager = new WebService::Cache::FileCacheManager('cache_dir'=>'/tmp/.api_cache/');
 my $cache_api = new WebService::Class::Twitter(username=>'username',password=>'password','cache_manager'=>$cache_manager);
-my $result $cache_api->public_timeline();
+my $result = $cache_api->public_timeline();
 
+memcached base cache
+
+my $cache_manager = new WebService::Cache::MemcachedCacheManager('servers'=>['127.0.0.1:11211']);
+my $api = new WebService::Class::HatenaHaiku(username=>'username',password=>'password','cache_manager'=>$cache_manager);
+my $result = $api->public_timeline();
 
 =head1 AUTHOR
 
