@@ -6,6 +6,8 @@ __PACKAGE__->mk_classdata('service_name');
 __PACKAGE__->mk_classdata('cache_manager');
 __PACKAGE__->mk_classdata('base_url');
 __PACKAGE__->mk_classdata('urls');
+__PACKAGE__->mk_classdata('username');
+__PACKAGE__->mk_classdata('password');
 __PACKAGE__->mk_accessors(qw/request_api/);
 
 
@@ -16,10 +18,11 @@ sub new{
 	return $self;
 }
 
-
 sub init{
 	my $self = shift;
-	my $args = shift;
+	my %args = @_;
+	$self->username($args{'username'});
+	$self->password($args{'password'});
 }
 
 
